import { Component, EventEmitter, Input, NgModule, Output } from '@angular/core';
import 'rxjs/Observable';
import 'rxjs/add/operator/distinctUntilChanged';
import { Subscription as Subscription$1 } from 'rxjs/Subscription';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @abstract
 */
class LoadingState {
    /**
     * @param {?} data
     * @return {?}
     */
    finishLoad(data) {
        this.error = false;
        this.loading = false;
        this.state = 'finish';
        if (data == null) {
            this.notFound = true;
        }
        else {
            this.notFound = false;
        }
    }
    /**
     * @return {?}
     */
    startLoad() {
        this.error = false;
        this.notFound = false;
        this.loading = true;
        this.state = 'start';
    }
    /**
     * @param {?} error
     * @return {?}
     */
    errorLoad(error) {
        this.error = true;
        this.loading = false;
        console.error(error);
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class SwsLoadingComponent extends LoadingState {
    constructor() {
        super();
        this.textNotFound = 'Данные отсутствуют.';
        this.textError = 'Ошибка загрузки данных. Повторите попытку чуть позже.';
        this.download = false;
        this.dataOut = new EventEmitter();
        this.downloadChange = false;
        this.subscription = new Subscription$1();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.oldObs = this.dataObservable;
        if (this.download && this.dataObservable) {
            this.loadData();
        }
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        // если используется состояние таба\аккордиона как критерий для загрузки
        if (typeof this.download === 'boolean') {
            // при первом открытии аккордиона\табы
            if (this.download && !this.downloadChange) {
                this.downloadChange = true;
                this.loadData();
            }
            // если был изменен observable и аккордион\таб открыт
            if (this.dataObservable !== this.oldObs && this.download) {
                this.loadData();
                this.oldObs = this.dataObservable;
            }
        }
        else {
            // если используется Observable как критерий для загрузки
            if (!changes['dataObservable'].firstChange) {
                this.loadData();
            }
        }
    }
    /**
     * @return {?}
     */
    loadData() {
        super.startLoad();
        this.subscription.add(this.dataObservable.distinctUntilChanged().subscribe(response => this.data = response, error => this.errorLoad(this.data, error), () => this.completeLoad(this.data)));
    }
    /**
     * @param {?} data
     * @return {?}
     */
    completeLoad(data) {
        console.log('completeLoad data', data);
        this.dataOut.emit(data);
        data = this.checkTypeData(data);
        super.finishLoad(data);
    }
    /**
     * @param {?} data
     * @param {?=} error
     * @return {?}
     */
    errorLoad(data, error) {
        console.log('errorLoad data', data);
        console.log('errorLoad error', error);
        // this.dataOut.emit(data);
        super.errorLoad(error);
    }
    /**
     * @param {?} data
     * @return {?}
     */
    checkTypeData(data) {
        if (this.isTable) {
            if (!data[0] || !data[1]) {
                return null;
            }
            else {
                return data;
            }
        }
        else {
            return data;
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.subscription.unsubscribe();
    }
}
SwsLoadingComponent.decorators = [
    { type: Component, args: [{
                selector: 'sws-loading-udfl, [sws-loading-udfl]',
                template: `<div *ngIf="notFound" class="algcenter">
    {{textNotFound}}
</div>
<!--<div *ngIf="error" class="algcenter">
    {{textError}}
    <span (click)="loadData()" style="cursor: pointer; color:#FF8F3A"> Попробуйте еще раз</span>
</div>-->
<div *ngIf="error" class="algcenter">{{textNotFound}}</div>
<div style="position: relative; min-height: 200px; overflow: hidden;">
    <div class="round" *ngIf="loading">
    </div>
    <div *ngIf="!notFound">
        <ng-content></ng-content>
    </div>
</div>
`,
                styles: [`.pane {
  padding: 1em; }

.hidden {
  visibility: hidden; }

.loading {
  opacity: 0.5; }

.algcenter {
  text-align: center; }

.center {
  margin-left: auto;
  margin-right: auto; }

.round {
  height: 100%;
  width: 100%;
  background-color: rgba(255, 255, 255, 0.55);
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  z-index: 2;
  border: 0; }
`]
            },] },
];
/** @nocollapse */
SwsLoadingComponent.ctorParameters = () => [];
SwsLoadingComponent.propDecorators = {
    "dataObservable": [{ type: Input },],
    "textNotFound": [{ type: Input },],
    "textError": [{ type: Input },],
    "download": [{ type: Input },],
    "isTable": [{ type: Input },],
    "dataOut": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class SwsLoadingModule {
}
SwsLoadingModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [SwsLoadingComponent],
                exports: [SwsLoadingComponent]
            },] },
];
/** @nocollapse */
SwsLoadingModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { SwsLoadingComponent, SwsLoadingModule, LoadingState };
//# sourceMappingURL=sws-loading-udfl.js.map
